LOLcat
======

Straight Python port of the Ruby version at https://github.com/busyloop/lolcat/
using not even half the code and no external dependancies.

It's a tool like cat, with added lulz.


Usage and examples
==================

![](https://github.com/tehmaze/lolcat/raw/master/lolcat.png)
